==> pegasus-support-2.0.5-sources.jar: com/thebeastshop/support/vo/exchange/ExchangeCoupon.java <==
package com.thebeastshop.support.vo.exchange;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by GFL on 2018/12/13.
 */
public class ExchangeCoupon implements Serializable {

    private static final long serialVersionUID = 1323006280193675722L;
    private String title;              //标题
    private String description;        //详细说明
    private String thresholdDesc;      // 门槛描述
    private String note;               // 备注
    private String logo;               // logo图片地址
    private Date startTime;            // 开始时间
    private Date expireTime;           // 过期时间
    private Integer days;              // 领取后N天

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getThresholdDesc() {
        return thresholdDesc;
    }

    public void setThresholdDesc(String thresholdDesc) {
        this.thresholdDesc = thresholdDesc;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
    }

    public Integer getDays() {
        return days;
    }

    public void setDays(Integer days) {
        this.days = days;
    }

    @Override
    public String toString() {
        return "ExchangeCoupon{" +
                "title='" + title + '\'' +
                ", description='" + description + '\'' +
                ", thresholdDesc='" + thresholdDesc + '\'' +
                ", note='" + note + '\'' +
                ", logo='" + logo + '\'' +
                ", startTime=" + startTime +
                ", expireTime=" + expireTime +
                ", days=" + days +
                '}';
    }
}

==> pegasus-support-2.7.5-sources.jar: com/thebeastshop/support/vo/exchange/ExchangeCoupon.java <==
package com.thebeastshop.support.vo.exchange;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by GFL on 2018/12/13.
 */
public class ExchangeCoupon implements Serializable {

    private static final long serialVersionUID = 1323006280193675722L;
    private String title;              //标题
    private String description;        //详细说明
    private String descImageUrl;       //详情图片
    private String thresholdDesc;      // 门槛描述
    private String note;               // 备注
    private String logo;               // logo图片地址
    private Date startTime;            // 开始时间
    private Date expireTime;           // 过期时间
    private Integer days;              // 领取后N天

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getDescImageUrl() {
        return descImageUrl;
    }

    public void setDescImageUrl(String descImageUrl) {
        this.descImageUrl = descImageUrl;
    }

    public String getThresholdDesc() {
        return thresholdDesc;
    }

    public void setThresholdDesc(String thresholdDesc) {
        this.thresholdDesc = thresholdDesc;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
    }

    public Integer getDays() {
        return days;
    }

    public void setDays(Integer days) {
        this.days = days;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("title", title)
                .append("description", description)
                .append("descImageUrl", descImageUrl)
                .append("thresholdDesc", thresholdDesc)
                .append("note", note)
                .append("logo", logo)
                .append("startTime", startTime)
                .append("expireTime", expireTime)
                .append("days", days)
                .toString();
    }
}
